.. _reference-index:

#################################
  Grok reference
#################################

:Release: |version|
:Date: |today|

   Grok means to understand so thoroughly that the observer becomes a part
   of the observed -- merge, blend, intermarry, lose identity in group
   experience. It means almost everything that we mean by religion,
   philosophy, and science -- it means as little to us (because we are from
   Earth) as color means to a blind man. -- `Robert A. Heinlein, Stranger in
   a Strange Land`


This is the grok reference documentation. It is organized by the Python
artefacts that implement the concepts.

Grok makes Zope 3 concepts more accessible for application developers. This
reference is not intended as introductory material for those concepts. Please
refer to the original Zope 3 documentation and the grok tutorial for
introductory material.


.. toctree::
   :maxdepth: 2

   core.rst
   components.rst
   directives.rst
   decorators.rst
   functions.rst
   events.rst
   exceptions.rst
